#!/bin/sh
# generates a simple report on test results for a specific id

TEST_VERSION=${TEST_VERSION:-"1.5"}

function main() {
  local _ids="$@"
  if test -z "$_ids"; then
    _ids=`find_ids | sort | uniq`
  fi
  for id in $_ids; do
    generate_report $id
  done
  echo
}

function generate_report() {
  local _id="$1"
  local _native_file="$_id-$TEST_VERSION.native"
  local _wine_file="$_id-$TEST_VERSION.wine"
  echo
  if test ! -f "$_native_file" -o ! -f "$_wine_file"; then
    echo "Missing one or more results files." > /dev/stderr
    exit 1
  fi

  echo "[$_id]"
  # create basic reports and generate summary files.
  process_file $_id $_native_file
  process_file $_id $_wine_file
  echo
  echo "== distinct native failures =="
  local _native_failures=`distinct_failures ${_native_file}.summary ${_wine_file}.summary`
  print_failures $_native_failures
  echo "== distinct wine failures =="
  local _wine_failures=`distinct_failures ${_wine_file}.summary ${_native_file}.summary`
  print_failures $_wine_failures
}

function print_failures() {
  local _failures="$@"
  if test -z "$_failures"; then
    echo "(none)"
    return
  fi
  for f in $_failures; do
    echo $f
  done
}

function process_file() {
  local _id="$1"
  local _file="$2"
  local _subid=${_file:${#_id} + 1}
  grep "FAIL: " $_file | sort > ${_file}.summary
  local _errcount=`wc -l ${_file}.summary | cut -d ' ' -f 1`
  echo "($_subid) failures : $_errcount"
}

# prints the failures in the first file not in the second file
function distinct_failures() {
  local _a="$1"
  local _b="$2"
  local _failed_tests=`diff "$_a" "$_b" | egrep "^<" | sed 's/^< FAIL: //'`
  echo -n $_failed_tests
}

function find_ids() {
  for file in `ls *.wine`; do
    echo $file | cut -d '-' -f 1
  done
}

main $@

